# Python 3 ANSS Formats Library

This is the Python implementation of the library used to generate and parse the 
ANSS Formats.

Dependencies
------
* ANSS Formats utilizes [JSON](www.json.org) for formatting.
* ANSS Formats was written in Python 3.6
* ANSS Formats uses [poetry](https://python-poetry.org/) for
Package, dependency and environment management.

Building
------
The steps to get and use the python ANSS-formats are as follows:

1. Clone ANSS-formats.
2. Open a command window and change directories to /python/
3. To run unit tests, run the command `poetry run pytest --cov=anssformats --junitxml junit.xml`

Using
-----S
Once you have the python distribution, simply import anssformats
